from .rival300csgofadeedition import rival300csgofadeedition

rival300csgohyperbeastedition = {
    "name": "SteelSeries Rival 300 CS:GO Hyperbeast Edition",

    "vendor_id": 0x1038,
    "product_id": 0x171a,
    "interface_number": 0,

    # Hyperbeast command mapping is same as CS:GO Fade Edition
    "commands": rival300csgofadeedition["commands"]
}
