from .rival300 import rival300

rival300dota2edition = {
    "name": "SteelSeries Rival 300 Dota 2 Edition",

    "vendor_id": 0x1038,
    "product_id": 0x1392,
    "interface_number": 0,

    "commands": rival300["commands"]

}
