from .rival import rival

rival300hpomen = {
    "name": "SteelSeries Rival 300 HP Omen Edition",

    "vendor_id": 0x1038,
    "product_id": 0x1718,
    "interface_number": 0,

    "commands": rival["commands"]
}
