from .rival300csgofadeedition import rival300csgofadeedition


rival300csgofadeeditionstm32 = {
    "name": "SteelSeries Rival 300 CS:GO Fade Edition (stm32)",

    "vendor_id": 0x1038,
    "product_id": 0x1716,
    "interface_number": 0,

    "commands": rival300csgofadeedition["commands"],

}
