from .rival100 import rival100

rival105 = {
    "name": "SteelSeries Rival 105 (Experimental)",

    "vendor_id": 0x1038,
    "product_id": 0x1814,
    "interface_number": 0,

    "commands": rival100["commands"]

}
