from .rival310 import rival310

rival310pubgedition = {
    "name": "SteelSeries Rival 310 PUBG Edition (Experimental)",

    "vendor_id": 0x1038,
    "product_id": 0x1736,
    "interface_number": 0,

    "rgbuniversal_format": rival310["rgbuniversal_format"],

    "commands": rival310["commands"],
}
